@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_BASE_TF_TYPE_H
 #define PXR_BASE_TF_TYPE_H
@@ -269,7 +252,10 @@ public:
 
     /// Return a C++ RTTI type_info for this type.
     ///
-    /// If this type is unknown or has not yet had a C++ type defined,
+    /// If this type is unknown, this will return a unique \c type_info
+    /// specifically for the unknown type.
+    ///
+    /// If this type has been declared, but not yet had a C++ type defined,
     /// \c typeid(void) will be returned.
     ///
     /// \see Define()
@@ -715,6 +701,20 @@ private:
                         bool isPodType,
                         bool isEnumType) const;
 
+    TF_API
+    static TfType const &_DeclareImpl(
+        const std::type_info &thisTypeInfo,
+        const std::type_info **baseTypeInfos,
+        size_t numBaseTypes);
+
+    TF_API
+    static TfType const &_DefineImpl(
+        const std::type_info &thisTypeInfo,
+        const std::type_info **baseTypeInfos,
+        _CastFunction *castFunctions,
+        size_t numBaseTypes,
+        size_t sizeofThisType, bool isPod, bool isEnum);
+
     // Execute the definition callback if one exists.
     void _ExecuteDefinitionCallback() const;
 
