@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_IMAGING_HD_RENDER_INDEX_H
 #define PXR_IMAGING_HD_RENDER_INDEX_H
@@ -441,13 +424,16 @@ private:
     // Allocate the next available instance id to the prim
     void _AllocatePrimId(HdRprim* prim);
 
+    using HdTaskCreateFnc =
+            std::function<HdTaskSharedPtr(HdSceneDelegate*, SdfPath const&)>;
+
     // Inserts the task into the index and updates tracking state.
     // _TrackDelegateTask is called by the inlined InsertTask<T>, so it needs
     // to be marked HD_API.
     HD_API
     void _TrackDelegateTask(HdSceneDelegate* delegate, 
                             SdfPath const& taskId,
-                            HdTaskSharedPtr const& task);
+                            HdTaskCreateFnc taskCreateFnc);
 
     template <typename T>
     static inline const TfToken & _GetTypeId();
@@ -593,11 +579,12 @@ template <typename T>
 void
 HdRenderIndex::InsertTask(HdSceneDelegate* delegate, SdfPath const& id)
 {
-    HD_TRACE_FUNCTION();
-    HF_MALLOC_TAG_FUNCTION();
+    auto createTask = [](HdSceneDelegate* _delegate, SdfPath const& _id) -> HdTaskSharedPtr
+    {
+        return std::make_shared<T>(_delegate, _id);
+    };
 
-    HdTaskSharedPtr task = std::make_shared<T>(delegate, id);
-    _TrackDelegateTask(delegate, id, task);
+    _TrackDelegateTask(delegate, id, createTask);
 }
 
 PXR_NAMESPACE_CLOSE_SCOPE
