@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_IMAGING_HD_ST_RESOURCE_REGISTRY_H
 #define PXR_IMAGING_HD_ST_RESOURCE_REGISTRY_H
@@ -29,13 +12,13 @@
 
 #include "pxr/imaging/hdSt/api.h"
 #include "pxr/imaging/hdSt/bufferArrayRegistry.h"
+#include "pxr/imaging/hdSt/enums.h"
 
 #include "pxr/imaging/hgi/hgi.h"
 
 #include "pxr/imaging/hd/bufferArrayRange.h"
 #include "pxr/imaging/hd/bufferSource.h"
 #include "pxr/imaging/hd/bufferSpec.h"
-#include "pxr/imaging/hd/enums.h"
 #include "pxr/imaging/hd/instanceRegistry.h"
 #include "pxr/imaging/hd/resourceRegistry.h"
 
@@ -161,7 +144,7 @@ public:
         /// file containing several grids, movie file containing frames).
         const HdStTextureIdentifier &textureId,
         /// Texture type, e.g., uv, ptex, ...
-        HdTextureType textureType,
+        HdStTextureType textureType,
         /// Sampling parameters such as wrapS, ...
         /// wrapS, wrapT, wrapR mode, min filer, mag filter
         const HdSamplerParameters &samplerParams,
@@ -188,7 +171,7 @@ public:
         /// file containing several grids, movie file containing frames).
         const HdStTextureIdentifier &textureId,
         /// Texture type, e.g., uv, ptex, ...
-        HdTextureType textureType);
+        HdStTextureType textureType);
 
     /// Sets how much memory a single texture can consume in bytes by
     /// texture type.
@@ -199,7 +182,7 @@ public:
     ///
     HDST_API
     void SetMemoryRequestForTextureType(
-        HdTextureType textureType,
+        HdStTextureType textureType,
         size_t memoryRequest);
 
     /// ------------------------------------------------------------------------
@@ -444,6 +427,22 @@ public:
     HdInstance<HgiComputePipelineSharedPtr>
     RegisterComputePipeline(HdInstance<HgiComputePipelineSharedPtr>::ID id);
 
+    /// Finds a sub resource registry for the given identifier if it already
+    /// exists or creates one by invoking the provided factory function.
+    ///
+    /// A sub resource registry is simply another resource registry defined
+    /// externally but whose lifetime is tied to this HdStResourceRegistry and
+    /// can be retrieved via this function.
+    ///
+    /// Any sub resource registries will have their Commit functions invoked
+    /// when Commit is invoked on this instance, and their GarbageCollect
+    /// functions invoked when GarbageCollect is invoked on this instance.
+    HDST_API
+    HdResourceRegistry*
+    FindOrCreateSubResourceRegistry(
+        const std::string& identifier,
+        const std::function<std::unique_ptr<HdResourceRegistry>()>& factory);
+
     /// Returns the global hgi blit command queue for recording blitting work.
     /// When using this global cmd instead of creating a new HgiBlitCmds we
     /// reduce the number of command buffers being created.
@@ -690,6 +689,11 @@ private:
     HdInstanceRegistry<HgiComputePipelineSharedPtr>
         _computePipelineRegistry;
 
+    using _SubResourceRegistryMap =
+        tbb::concurrent_unordered_map<std::string,
+                                    std::unique_ptr<HdResourceRegistry>>;
+    _SubResourceRegistryMap _subResourceRegistries;
+
     HgiBlitCmdsUniquePtr _blitCmds;
     HgiComputeCmdsUniquePtr _computeCmds;
 
