@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_SDF_LAYER_H
 #define PXR_USD_SDF_LAYER_H
@@ -101,7 +84,7 @@ class SdfLayer
 public:
     /// Destructor
     SDF_API
-    virtual ~SdfLayer() noexcept; // noexcept needed for std::atomic member
+    virtual ~SdfLayer(); 
 
     /// Noncopyable
     SdfLayer(const SdfLayer&) = delete;
@@ -836,18 +819,31 @@ public:
     void SetComment(const std::string &comment);
     
     /// Return the defaultPrim metadata for this layer.  This field
-    /// indicates the name of which root prim should be targeted by a reference
-    /// or payload to this layer that doesn't specify a prim path.
+    /// indicates the name or path of which prim should be targeted by a
+    /// reference or payload to this layer that doesn't specify a prim path.
     ///
     /// The default value is the empty token.
     SDF_API
     TfToken GetDefaultPrim() const;
 
-    /// Set the default prim metadata for this layer.  The root prim with this
-    /// name will be targeted by a reference or a payload to this layer that
-    /// doesn't specify a prim path.  Note that this must be a root prim
-    /// <b>name</b> not a path.  E.g. "rootPrim" rather than "/rootPrim".  See
-    /// GetDefaultPrim().
+    /// Return this layer's default prim metadata interpreted as an absolute 
+    /// prim path regardless of whether it was authored as a root prim name or a
+    /// prim path. For example, if the authored default prim value is 
+    /// "rootPrim", return </rootPrim>. If the authored default prim value is 
+    /// "/path/to/non/root/prim", return </path/to/non/root/prim>. If the 
+    /// authored default prim value cannot be interpreted as a prim path, 
+    /// return the empty SdfPath.
+    ///
+    /// The default value is an empty path.
+    SDF_API
+    SdfPath GetDefaultPrimAsPath() const;
+
+    /// Set the default prim metadata for this layer.  The prim at this path
+    /// will be targeted by a reference or a payload to this layer that doesn't 
+    /// specify a prim path.
+    /// Note that this can be a name if it refers to a root prim, or a path to
+    /// any prim in this layer. E.g. "rootPrim", "/path/to/non/root/prim" or
+    /// "/rootPrim".  See GetDefaultPrim().
     SDF_API
     void SetDefaultPrim(const TfToken &name);
 
@@ -1217,6 +1213,37 @@ public:
     SDF_API
     void SetSubLayerOffset(const SdfLayerOffset& offset, int index);
 
+    /// @}
+    /// \name Relocates
+    /// @{
+
+    /// Get the list of relocates specified in this layer's metadata.
+    ///
+    /// Each individual relocate in the list is specified as a pair of 
+    /// \c \SdfPath where the first is the source path of the relocate and the
+    /// second is target path.
+    ///
+    /// Note that is NOT a proxy object and cannot be used to edit the field in
+    /// place. 
+    SDF_API
+    SdfRelocates GetRelocates() const;
+    
+    /// Set the entire list of namespace relocations specified on this layer to
+    /// \p relocates.
+    SDF_API
+    void SetRelocates(const SdfRelocates& relocates);
+
+    /// Returns true if this layer's metadata has any relocates opinion, 
+    /// including that there should be no relocates (i.e. an empty list).  An 
+    /// empty list (no relocates) does not mean the same thing as a missing list
+    /// (no opinion).
+    SDF_API
+    bool HasRelocates() const;
+    
+    /// Clears the layer relocates opinion in the layer's metadata.
+    SDF_API
+    void ClearRelocates();
+
     /// @}
 
     /// \name Detached Layers
@@ -1820,9 +1847,8 @@ private:
     // users to export and save to any file name, regardless of extension.
     bool _WriteToFile(const std::string& newFileName, 
                       const std::string& comment, 
-                      SdfFileFormatConstPtr fileFormat = TfNullPtr,
-                      const FileFormatArguments& args = FileFormatArguments())
-                      const;
+                      SdfFileFormatConstPtr fileFormat,
+                      const FileFormatArguments& args) const;
 
     // Swap contents of _data and data. This operation does not register
     // inverses or emit change notification.
