@@ -1,25 +1,8 @@
 #
 # Copyright 2016 Pixar
 #
-# Licensed under the Apache License, Version 2.0 (the "Apache License")
-# with the following modification; you may not use this file except in
-# compliance with the Apache License and the following modification to it:
-# Section 6. Trademarks. is deleted and replaced with:
-#
-# 6. Trademarks. This License does not grant permission to use the trade
-#    names, trademarks, service marks, or product names of the Licensor
-#    and its affiliates, except as required to comply with Section 4(c) of
-#    the License and to reproduce the content of the NOTICE file.
-#
-# You may obtain a copy of the Apache License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the Apache License with the above modification is
-# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-# KIND, either express or implied. See the Apache License for the specific
-# language governing permissions and limitations under the Apache License.
+# Licensed under the terms set forth in the LICENSE.txt file available at
+# https://openusd.org/license.
 #
 
 # pylint: disable=round-builtin
@@ -376,9 +359,7 @@ class LayerInfo(object):
         realPath = ''
         try:
             resolver = Ar.GetResolver()
-            with Ar.ResolverContextBinder(stage.GetPathResolverContext()):
-                realPath = resolver.Resolve(resolver.CreateIdentifier(
-                    identifier, parentLayer.resolvedPath)).GetPathString()
+            realPath = resolver.Resolve(identifier).GetPathString()
         except Exception as e:
             PrintWarning('Failed to resolve identifier {} '
                          .format(identifier), e)
@@ -434,13 +415,6 @@ class LayerInfo(object):
             Sdf.Layer.GetDisplayNameFromIdentifier(self._identifier))
 
 def _AddLayerTree(stage, layerTree, depth=0):
-    layers = [LayerInfo.FromLayer(
-        layerTree.layer, stage, layerTree.offset, depth)]
-    for child in layerTree.childTrees:
-        layers.extend(_AddLayerTree(stage, child, depth=depth + 1))
-    return layers
-
-def _AddLayerTreeWithMutedSubLayers(stage, layerTree, depth=0):
 
     layers = [LayerInfo.FromLayer(
         layerTree.layer, stage, layerTree.offset, depth)]
@@ -452,31 +426,38 @@ def _AddLayerTreeWithMutedSubLayers(stage, layerTree, depth=0):
     # layers in the correct sublayer position, we go through the sublayer paths
     # parsing either the muted layer or a layer stack tree subtree.
     # 
-    # XXX: It would be nice if we could get this whole layer stack tree with
-    # muted layers and composed offsets without having to cross reference two
-    # different APIs. 
+    # The layer tree will also not have any entries for layers that failed to
+    # load. We need to handle this case as well.
     childTrees = layerTree.childTrees
     subLayerPaths = layerTree.layer.subLayerPaths
     childTreeIter = iter(layerTree.childTrees)
-    numMutedLayers = 0
+    numMissingLayers = 0
     for subLayerPath in subLayerPaths:
-        if stage.IsLayerMuted(subLayerPath):
+        anchoredSubLayerPath = Sdf.ComputeAssetPathRelativeToLayer(
+            layerTree.layer, subLayerPath)
+        if stage.IsLayerMuted(anchoredSubLayerPath):
             # The sublayer path is muted so add muted layer by path. We don't 
             # recurse on sublayers for muted layers.
             layers.append(LayerInfo.FromMutedLayerIdentifier(
-                subLayerPath, layerTree.layer, stage, depth=depth+1))
-            numMutedLayers = numMutedLayers + 1
+                anchoredSubLayerPath, layerTree.layer, stage, depth=depth+1))
+            numMissingLayers = numMissingLayers + 1
+        elif not Sdf.Layer.Find(anchoredSubLayerPath):
+            # Otherwise, the sublayer failed to load for some other reason.
+            # Just skip it to maintain current behavior; in the future, we
+            # may want to show an entry with some annotation to tell the
+            # user about this sublayer.
+            numMissingLayers = numMissingLayers + 1
         else:
             # Otherwise we expect the unmuted sublayer to be the next child
             # tree in the layer stack tree so we recursively add it.
-            layers.extend(_AddLayerTreeWithMutedSubLayers(
+            layers.extend(_AddLayerTree(
                 stage, next(childTreeIter), depth=depth + 1))
 
     # Since we're relying on the correspondence between the unmuted sublayer 
     # paths and the child layer stack trees, report an error if the total number
     # of muted layers and child trees don't match up so we can track if it 
     # becomes an issue.
-    if numMutedLayers + len(childTrees) != len(subLayerPaths):
+    if numMissingLayers + len(childTrees) != len(subLayerPaths):
         print("CODING ERROR: Encountered an unexpected number of muted "
               "sublayers of layer {}. The root layer stack may be "
               "incorrect in the layer stack view".format(
@@ -488,9 +469,7 @@ def GetRootLayerStackInfo(stage):
     primIndex = stage.GetPseudoRoot().GetPrimIndex()
     layerStack = primIndex.rootNode.layerStack
 
-    if layerStack.mutedLayers:
-        return _AddLayerTreeWithMutedSubLayers(stage, layerStack.layerTree)
-    else:
+    with Ar.ResolverContextBinder(stage.GetPathResolverContext()):
         return _AddLayerTree(stage, layerStack.layerTree)
 
 def PrettyFormatSize(sz):
